@@ -237,13 +237,7 @@ class Analyzer:
             
         
         return data_array_norm
-        
-
-
-    
-
-
-
+     
     
     def calc_psd(self, data_array, sample_rate):
         """
@@ -281,8 +275,6 @@ class Analyzer:
         offset = np.mean(data_array, axis=1)
         return offset
 
-
-    
             
     def fit_didv(self, data_array=None, sample_rate=None, unit='Amps',
                  mask=None, fit_config=None, add_autocuts=True):
@@ -438,8 +430,10 @@ class Analyzer:
             r0 = analysis_config['r0'][ichan]
             rp = analysis_config['rp'][ichan]
             dt = analysis_config['dt'][ichan]
-            add180phase=analysis_config['add_180phase'][ichan]
+            add180phase = analysis_config['add_180phase'][ichan]
+            tes_bias = analysis_config['tes_bias'][ichan]
 
+            
             if add_autocuts:
                 cut = qp.autocuts_didv(
                     traces,
@@ -475,78 +469,88 @@ class Analyzer:
                 fit_array = np.zeros((nb_channels,nb_samples),
                                      dtype=np.float64)
                 
-            data_array_truncated[ichan,:] = (didv_inst._tmean - didv_inst._offset)*norm
-          
-            
+            data_array_truncated[ichan,:] = (didv_inst._tmean
+                                             - didv_inst._offset)*norm
+
+            # apply low pass
+            nyq = sample_rate/2
+            cut_off = 30000/nyq
+            b,a = signal.butter(2, cut_off)
+            data_array_truncated[ichan,:] = (
+                signal.filtfilt(b, a, data_array_truncated[ichan,:], axis=-1,
+                                padtype='even')
+            )
+                  
             # fit
             result = None
+            poles = None
             if do_fit_1pole:
                 print('Info: Starting dIdV 1-pole Fit')
                 didv_inst.dofit(1)
                 result = didv_inst.fitresult(1)
+                poles = 1
                 print('Info: dIdV 1-pole Fit Done')
 
             if do_fit_2pole:
                 print('Info: Starting dIdV 2-pole Fit')
                 didv_inst.dofit(2)
                 result = didv_inst.fitresult(2)
+                poles = 2
                 print('Info: dIdV 2-pole Fit Done')
 
             if do_fit_3pole:
                 print('Info: Starting dIdV 3-pole Fit')
                 didv_inst.dofit(3)
                 result = didv_inst.fitresult(3)
+                poles = 3
                 print('Info: dIdV 3-pole Fit Done')
 
-
-
-            # Calculate R0/I0/P0 (infinite loop
-            # approximation)
-            if ((do_fit_2pole or do_fit_3pole)
-                and 'smallsignalparams' in result):
-                didv = result['didv0']
-                tes_bias = self._analysis_config['tes_bias'][ichan]
-              
-                # R0
-                r0_infinite = (abs(1/didv) + rp + rshunt)
-
-                # IO
-                i0_infinite = (tes_bias*rshunt)/(r0_infinite+rshunt+rp)
-
-                # P0
-                p0_infinite = tes_bias*rshunt*i0_infinite - (rp + rshunt)*pow(i0_infinite,2)
-                result['infinite_l'] = dict()
-                result['infinite_l']['r0'] = r0_infinite
-                result['infinite_l']['i0'] = i0_infinite
-                result['infinite_l']['p0'] = p0_infinite
+            # Calculate R0/I0/P0 (infinite loop approximation)
+            ilg_params = None
+            if (do_fit_2pole or do_fit_3pole):
+                ilg_params = qp.get_biasparams_ilg(
+                    result['params'], result['cov'],
+                    tes_bias, tes_bias*0.05,
+                    rshunt, rp)
             
+            # calc small signal parameters
+            didv_inst.calc_smallsignal_params(
+                biasparams=ilg_params,
+                poles=poles
+            )
 
-                
             # Add result to list
-            result_list.append(result)
+            if do_fit_1pole:
+                result = didv_inst.fitresult(1)
+            if do_fit_2pole:
+                result = didv_inst.fitresult(2)
+            if do_fit_3pole:
+                result = didv_inst.fitresult(3)
 
+            if do_fit_2pole or do_fit_3pole:
+                # add infinite loop gain parameters
+                result['infinite_l'] = dict()
+                result['infinite_l']['r0'] = ilg_params['r0']
+                result['infinite_l']['i0'] = ilg_params['i0']
+                result['infinite_l']['p0'] = ilg_params['p0']
+                
+            result_list.append(result)
+         
             # Fitted response
             dt = 1/sample_rate
             time = np.arange(0,nb_samples)*dt
-                      
-            key = 'params'
-            if 'smallsignalparams' in result:
-                key = 'smallsignalparams'
-
             fit_array[ichan,:] = norm*qp.squarewaveresponse(
                 time,
                 sg_current,
                 sg_freq,
-                dutycycle,
-                **result[key],)
-            
+                result['params'],
+                dutycycle=dutycycle,
+                rsh=rshunt)
+                        
         didv_data_dict['fit_array'] = fit_array
         didv_data_dict['results'] = result_list
             
         return data_array_truncated, didv_data_dict
-
-
-
     
     
     def _store_data(self, data_array, cuts_val):
@@ -612,14 +616,16 @@ class Analyzer:
             nb_to_delete = self._nb_events_running_avg-self._analysis_config['nb_events_avg']+1
             
             # data buffer
-            self._data_buffer = np.delete(self._data_buffer, list(range(nb_to_delete)), axis=2)
+            self._data_buffer = np.delete(self._data_buffer,
+                                          list(range(nb_to_delete)), axis=2)
 
             # cut buffer
             if self._analysis_config['enable_pileup_rejection']:
                 for cut_name,val in self._cut_buffer.items():
-                    self._cut_buffer[cut_name] = np.delete(val,
-                                                            list(range(nb_to_delete)),
-                                                            axis=1)
+                    self._cut_buffer[cut_name] = np.delete(
+                        val,
+                        list(range(nb_to_delete)),
+                        axis=1)
                 
         # append elements
         self._data_buffer = np.append(self._data_buffer, data_array, axis=2)
@@ -801,10 +807,7 @@ class Analyzer:
         
 
         return cuts_val
-    
-
   
-
         
         
     def _initialize_config(self):
@@ -827,7 +830,7 @@ class Analyzer:
         self._analysis_config['tes_bias'] = None
         self._analysis_config['rshunt'] = 0.005
         self._analysis_config['rp'] = 0.003
-        self._analysis_config['r0'] = 0.2
+        self._analysis_config['r0'] = 0.1
         self._analysis_config['dt'] = 2e-6
         self._analysis_config['add_180phase'] = False
         self._analysis_config['fit_didv'] = False
