@@ -10,6 +10,7 @@ import sys
 import copy
 from datetime import datetime
 import time
+import copy
 
 from pytesdaq.utils import connection_utils
 
@@ -167,18 +168,20 @@ class Config:
             print('WARNING: Problem reading settings file for "'+
                   measurement_name + '" measurement!')
 
-        return output_setup 
+        output_setup_copy = copy.deepcopy(output_setup)
+            
+        return output_setup_copy
 
 
   
     def get_squid_controller(self):
         """
-        get SQUID/TES controller device name
+        get SQUID controller device name
         
         Returns:
-           str - no type conversion happens here!
+           str or NoneType
         """
-        controller=str()
+        controller = None
         try:
             controller =  self._get_setting('setup','squid_controller')
         except:
@@ -186,8 +189,22 @@ class Config:
     
         return controller
 
-
-
+    def get_tes_controller(self):
+        """
+        get TES controller device name
+        
+        Returns:
+           str or NoneType
+        """
+        
+        controller = None
+        try:
+            controller =  self._get_setting(
+                'setup','tes_controller')
+        except:
+            pass
+    
+        return controller
 
     def get_temperature_controllers(self):
         """
@@ -197,26 +214,25 @@ class Config:
         Returns:
             list of strings - no type conversion happens here!
         """
-        controllers=list()
+        controllers = list()
         
         try:
-            controllers =  self._get_comma_separated_setting('setup','temperature_controllers')
+            controllers =  self._get_comma_separated_setting(
+                'setup','temperature_controllers')
         except:
             pass
         
         return controllers
 
 
-
-
     def get_signal_generator(self):
         """
         get signal generator device name
             
         Returns:
-             str - no type conversion happens here!
+             str o NoneType
         """
-        controller=str()
+        controller = None
         try:
             controller = self._get_setting('setup','signal_generator')
         except:
@@ -225,7 +241,6 @@ class Config:
         return controller
 
 
-
     def enable_redis(self):
         """
         Enable redis
@@ -308,14 +323,13 @@ class Config:
         if controller_name is None:
             controller_name = self.get_squid_controller()
 
-
-        if self._has_setting(controller_name,'preamp_fix_gain') and controller_name is not None:
-            preamp_fix_gain =  float(self._get_setting(controller_name,'preamp_fix_gain'))
-            
+        if (controller_name is not None
+            and self._has_setting(controller_name,'preamp_fix_gain')):
+            preamp_fix_gain =  float(self._get_setting(controller_name,
+                                                       'preamp_fix_gain'))
+                   
             
         return preamp_fix_gain
-
-
     
     
     def get_feedback_fix_gain(self, controller_name=None):
@@ -329,16 +343,13 @@ class Config:
         if controller_name is None:
             controller_name = self.get_squid_controller()
 
-
-        if self._has_setting(controller_name,'feedback_fix_gain') and controller_name is not None:
-            feedback_fix_gain =  float(self._get_setting(controller_name,'feedback_fix_gain'))
-            
+        if (controller_name is not None
+            and self._has_setting(controller_name,'feedback_fix_gain')):
+            feedback_fix_gain =  float(self._get_setting(controller_name,
+                                                         'feedback_fix_gain'))
             
         return feedback_fix_gain
 
-
-
-
     
     def get_output_fix_gain(self, controller_name=None):
         """
@@ -349,36 +360,20 @@ class Config:
         if controller_name is None:
             controller_name = self.get_squid_controller()
 
-        
-        if self._has_setting(controller_name,'output_fix_gain') and controller_name is not None:
-            output_fix_gain =  float(self._get_setting(controller_name,'output_fix_gain'))
-            
+        if (controller_name is not None
+            and self._has_setting(controller_name,'output_fix_gain')):
+            output_fix_gain =  float(self._get_setting(controller_name,
+                                                       'output_fix_gain'))
+                   
         return output_fix_gain
 
-
     
-
-    def get_signal_gen_tes_resistance(self, controller_name=None):
-        """
-        Get SQUID readout output driver fix gain
-        """
-        resistance = nan
-
-        if controller_name is None:
-            controller_name = self.get_squid_controller()
-
-        
-        if self._has_setting(controller_name,'signal_gen_tes_resistance') and controller_name is not None:
-            resistance  =  float(self._get_setting(controller_name,'signal_gen_tes_resistance'))
-            
-        return resistance
-
-
     
     def get_adc_list(self):
         adc_list = list()
         try:
-            adc_list =  self._get_comma_separated_setting('setup','enable_adc')
+            adc_list =  self._get_comma_separated_setting(
+                'setup', 'enable_adc')
         except:
             pass
         
@@ -428,9 +423,9 @@ class Config:
         connection_table = pd.DataFrame(adc_connections, columns = column_list)
         setup['connection_table'] = connection_table
         
-
-
-        return setup
+        setup_copy = copy.deepcopy(setup)
+         
+        return setup_copy
 
      
     def get_adc_connections(self, adc_id=None):
@@ -456,7 +451,7 @@ class Config:
             if connection_table_list:
                 connection_table = pd.concat(connection_table_list)
             
-        return connection_table 
+        return connection_table.copy() 
 
 
     
@@ -471,11 +466,13 @@ class Config:
 
         # check arguments
         if  adc_id is None or adc_channel_list is None:
-            raise ValueError('ERROR in get_detector_config: "adc_id" and "adc_channel_list" required!')
+            raise ValueError('ERROR in get_detector_config: "adc_id" and '
+                             '"adc_channel_list" required!')
 
         adc_list = self.get_adc_list()
         if adc_id not in adc_list:
-            raise ValueError('ERROR in get_detector_config: No information in setup file for "'
+            raise ValueError('ERROR in get_detector_config: No information '
+                             + 'in setup file for "'
                              + str(acd_id) + '"!')
 
 
@@ -484,27 +481,23 @@ class Config:
                       'output_gain','preamp_gain','feedback_polarity','feedback_mode',
                       'signal_source','signal_gen_current','signal_gen_frequency',
                       'squid_turn_ratio','shunt_resistance', 'feedback_resistance',
-                      'parasitic_resistance',
-                      'signal_gen_tes_resistance','close_loop_norm']
-        
+                      'parasitic_resistance', 'tes_bias_resistance',
+                      'signal_gen_resistance','close_loop_norm']
+             
         detector_config = dict()
         for param in param_list:
             detector_config[param] = list()
-            
 
         # store channel lost
         detector_config['adc_name'] = adc_id
         detector_config['channel_type'] = 'adc'
         detector_config['channel_list'] = adc_channel_list
-
-
             
         # loop channel list
         for adc_chan in adc_channel_list:
             item = 'detector_config' + str(adc_chan)
             if not self._has_setting(adc_id, item):
-                raise ValueError('ERROR in get_detector_config: No detector settings found for channel '
-                                 + str(adc_chan) + '!')
+                continue
 
             settings = self._get_comma_separated_setting(adc_id, item)
             for param in settings:
@@ -513,7 +506,9 @@ class Config:
                 param_val = float(param_split[1])
 
                 # some conversion needed
-                if param_name=='tes_bias' or param_name=='squid_bias' or param_name=='signal_gen_current':
+                if (param_name=='tes_bias'
+                    or param_name=='squid_bias'
+                    or param_name=='signal_gen_current'):
                     param_val = param_val/1000000.0
                 if param_name=='lock_point_voltage':
                     param_val = param_val/1000.0
@@ -521,8 +516,8 @@ class Config:
                 # add in config
                 detector_config[param_name].append(param_val)
 
-                       
-        return detector_config 
+        detector_config_copy = copy.deepcopy(detector_config)
+        return detector_config_copy
 
     def get_visa_library(self):
         """
@@ -532,6 +527,7 @@ class Config:
             str - no type conversion happens here!
         """
         library_path = None
+        
         try:
             if self._has_setting('setup','visa_library'):
                 library_path =  self._get_setting('setup','visa_library')
@@ -548,7 +544,7 @@ class Config:
         Returns:
             str - no type conversion happens here!
         """
-        address=str()
+        address = str()
         try:
             address =  self._get_setting('feb','visa_address')
         except:
@@ -653,52 +649,78 @@ class Config:
             traceback.print_exc()
 
         return info
-
-
-    def get_signal_generator_visa_address(self, device_name):
-        """
-        get function generators
-        
-        Returns:
-            str - no type conversion happens here!
-        """
-
-        key = device_name + '_visa_address'
-        
-        address=str()
-        try:
-            address =  self._get_setting('signal_generators',key)
-        except:
-            pass
     
+    def get_device_visa_address(self, device_name):
+        """
+        get visa address of a device assuming:
+        [device_name]
+           visa_address = ...
+
+        """
+
+        address = None
+        
+        # back compatibility if device is "keysight"
+        if device_name == 'keysight':
+            key = 'keysight_visa_address'
+            if self._has_setting('signal_generators', key):
+                address =  str(self._get_setting('signal_generators', key))
+                return address
+            else:
+                # it has been rename to agilent33500B
+                device_name = 'agilent33500B'
+
+                
+        if self._has_setting(device_name, 'visa_address'):
+            address = str(self._get_setting(device_name, 'visa_address'))
+            
         return address
 
-
-    def get_signal_generator_attenuation(self, device_name):
-        """
-        get function generator attenuation 
-
-        Parameters:
-        ----------        
-        device_name : str
-          signal generator name (field in .ini configuration file)
- 
-        Returns:
-        --------
-            attenuation : float
-        """
-
-        key = device_name + '_attenuation'
     
-        attenuation = 1
-        try:
-            attenuation =  float(self._get_setting('signal_generators', key))
-        except:
-            pass
-    
-        return attenuation
+    def get_device_parameters(self, device_name, parameter=None):
+        """
+        get visa address of a device assuming:
+        [device_name]
+           visa_address = ...
 
+        """
+        
+        # back compatibility if device is "keysight"
+        # (only "attenuation" available)
+        parameters = dict()
+        
+        if device_name == 'keysight':
 
+            if self._has_section('signal_generators'):
+                key = 'keysight_attenuation'
+                if self._has_setting('signal_generators', key):
+                    parameters['attenuation'] = (
+                        float(self._get_setting('signal_generators', key))
+                    )
+                else:
+                    parameters['attenuation'] = None
+                    
+                if parameter == 'attenuation':
+                    return parameters['attenuation']
+                else:
+                    return parameters
+            else:
+                device_name = 'agilent33500B'
+
+        parameters = None
+        if self._has_section(device_name):
+            
+            parameters = self._get_section_dict(device_name)
+
+            if parameter is not None:
+                if parameter in parameters.keys():
+                    parameters = parameters[parameter]
+                else:
+                    parameters = None
+
+        return parameters
+
+   
     def get_temperature_controller_setup(self, device_name):
         """
         get function generators
@@ -766,27 +788,25 @@ class Config:
         except:
             raise ValueError('ERROR: Unknown temperature_controllers format!')
                 
-        
-        return output_dict
+        output_dict_copy = copy.deepcopy(output_dict)
+        return output_dict_copy
 
 
-    def get_daq_config(self, trigger_type):
+    def get_daq_config(self, acquisition_type):
         """
         Get daq config by trigger type
         """
-        if  not self._has_section(trigger_type):
-            print('ERROR: Trigger type "' + trigger_type + '" '
-                  + 'not recognized. Available types: '
-                  + 'continuous, randoms, didv, threshold')
-            print('Check code...')
+        
+        if  not self._has_section(acquisition_type):
             return None
 
-        return self._get_section_dict(trigger_type)
+        daq_config = copy.deepcopy(
+            self._get_section_dict(acquisition_type)
+        )
 
-        
-        
-    
+        return daq_config
 
+      
     
     def _get_ini_path(self, ini_filename):
         """
@@ -819,7 +839,6 @@ class Config:
         return self._cached_config.items(section) 
 
 
-
     def _has_section(self, section):
         """
         check is section exist
@@ -856,8 +875,6 @@ class Config:
         return self._cached_config.get(section, name) 
 
 
-    
-
     def _has_setting(self, section, name):
         """
         check is setting exist
